
/* bpf.c: BPF interface functions
 *
 * Routines for network traffic sniffing.
 *
 * Rui Ribeiro  <ruiribeiro@users.sourceforge.net>
 * Jose Caetano <jcaetano@users.sourceforge.net>
 *
 * Copyright Rui Ribeiro & Jose Silva
 * Licensed under GNU. Read ./LICENSE for the legalese.
 *
 */
/*
 * bpf.c: Rotinas de interface com Berkeley Packet Filter.
 *
 * Contem as rotinas necessarias para realizar a interface com a biblioteca
 * de escuta de trafego na rede.
 *
 */

#include <stdio.h>
#include <pcap.h>
#include "h/prototypes.h"

int medium;

/*
 * sniffer_bpf: main sniffer routine
 */
int sniffer_bpf(char * cmdbuf, char * arg_device, int promisc)
   {
   char *device, ebuf[PCAP_ERRBUF_SIZE];
   u_char * user;
   int npacs = - 1;
   int err;
   bpf_u_int32 netp, netmask;
   struct bpf_program fcode;
   static pcap_t *pd;
   int snap_len = 100;
   int pcap_timeout = 1000;

   device = arg_device;
   if(!strcmp(device, ""))
   {
   device = pcap_lookupdev(ebuf);
   if (device == NULL)
      {
      fprintf(stderr, "pcap_lookupdev: %s\n", ebuf);
      exit(1);
      }
      else
         info(device);
   }

   /* device = "eth0"; */
   if ( pcap_lookupnet(device, &netp, &netmask, ebuf) == -1 )
      {
      fprintf(stderr, "pcap_lookupnet: %s\n", ebuf);
      }
   // else
   //  fprintf(stderr, "Network device number = %x, mask = %x\n", netp, netmask);

   pd = pcap_open_live(device, snap_len, promisc, pcap_timeout, ebuf);
   if(pd == NULL)
      {
      fprintf(stderr, "pcap_open_live: %s\n", ebuf);
      exit(1);
      }
   if(pcap_compile(pd, &fcode, cmdbuf, 1, netmask)<0)
      {
      fprintf(stderr, "pcap_compile: %s\n", pcap_geterr(pd));
      exit(1);
      }
   medium = pcap_datalink(pd);
   if( pcap_loop(pd, npacs, callback_f, user) == -1 )
      {
      fprintf(stderr, "pcap_loop: %s\n", pcap_geterr(pd));
      }
      /*
   while(1)
      if(pcap_dispatch(pd, 0, callback_f, user) == -1 )
         {
         } 
       */
   return(0);
   }

/* EOF
 */
 
