//******************************************************************************
// Project: Simple LAN Monitor v1.10
// URL:		http://slam.sourceforge.net
// File:    ServerStub.java
//
// Description:
//          Creates a TCP/IP server stub to emulate the real server, for
//          teting proposes of the SimpleLANMonitorApplet and 
//          SimpleLANMonitorFrame Java classes.
//
// Copyright (C) 2001:
//          Jos Caetano Silva (jcaetano@users.sourceforge.net)
//          Rui Fernando Ribeiro (ruiribeiro@users.sourceforge.net)
//
// Licence:
//          This program is free software; you can redistribute it and/or modify
//          it under the terms of the GNU General Public License as published by
//          the Free Software Foundation (read the 'GNU General Public 
//          License.htm' file, for more details).
// 
//          This program is distributed in the hope that it will be useful,
//          but WITHOUT ANY WARRANTY; without even the implied warranty of
//          MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
//          GNU General Public License for more details.
// 
//          You should have received a copy of the GNU General Public License
//          along with this program; if not, write to the Free Software
//          Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
//******************************************************************************

import java.lang.Character;
import java.lang.Integer;
import java.awt.*;
import java.awt.event.*;
import java.net.*;
import java.io.OutputStream;
import java.io.IOException;
import java.util.ResourceBundle;
import java.util.Random;

import MessageBox;


/**
 * This class can take a variable number of parameters on the command
 * line. Program execution begins with the main() method. The class
 * constructor is not invoked unless a window frame of type 
 * 'ServerStub' is created in the main() method.
 * 
 * @author	Jos Caetano Silva (jcaetano@users.sourceforge.net)
 * @author  Rui Fernando Ribeiro (ruiribeiro@users.sourceforge.net)
 * 
 * @version 1.10, 2001-11-11
 * @sice 1.10
 */
public class ServerStub extends Frame
	                    implements WindowListener,
								   ActionListener {
	/* Private members */
	// Internacional resourses support
	private ResourceBundle m_ResourcesBundle = ResourceBundle.getBundle("SSResources", getLocale());

	/**
	 * Menu objects.
	 */
    private MenuBar menuBar = new MenuBar();
    private Menu menuFile = new Menu(m_ResourcesBundle.getString("MenuFileKey"));
    private Menu menuHelp = new Menu(m_ResourcesBundle.getString("MenuHelpKey"));
    private MenuItem menuItemFileExit = new MenuItem(m_ResourcesBundle.getString("MenuFileExitKey"), new MenuShortcut((int)((Character)m_ResourcesBundle.getObject("MenuFileExit_Key")).charValue()));
	private MenuItem menuItemHelpLicence = new MenuItem(m_ResourcesBundle.getString("MenuHelpLicenceKey"), new MenuShortcut((int)((Character)m_ResourcesBundle.getObject("MenuHelpLicence_Key")).charValue()));
	private MenuItem menuItemHelpAbout = new MenuItem(m_ResourcesBundle.getString("MenuHelpAboutKey"), new MenuShortcut((int)((Character)m_ResourcesBundle.getObject("MenuHelpAbout_Key")).charValue()));
	
	/**
	 * Window obejects
	 */
	private Image m_FrameIcon = null;
	private Label m_labelTraffic = new Label("          ");
	private Label m_labelStatusBar = new Label("");
 	
	private int m_iPort = 0;
	private boolean m_bRunnig = true;
		   
	/**
	 * Contructor for the ServerStub frame class.
	 */
	public ServerStub(int i)
	{
		super();
		
		m_iPort = i;
		DialogInit();
	}
	
	private void DialogInit()
	{
		// Menu stuf
		menuItemFileExit.addActionListener(this);
		menuItemHelpLicence.addActionListener(this);
		menuItemHelpAbout.addActionListener(this);
		
		menuFile.add(menuItemFileExit);
		
		menuHelp.add(menuItemHelpLicence);
		menuHelp.add(new MenuItem("-"));
		menuHelp.add(menuItemHelpAbout);
			
		menuBar.add(menuFile);
		menuBar.setHelpMenu(menuHelp);
		
		this.setMenuBar(menuBar);
		
		// Frame stuf
		m_FrameIcon = Toolkit.getDefaultToolkit().getImage("AppIcon.gif");
		
		this.setIconImage(m_FrameIcon);
		this.addWindowListener(this);
		this.setTitle(m_ResourcesBundle.getString("TitleKey"));
		this.setBackground((Color)SystemColor.control);
		this.setForeground((Color)SystemColor.controlText);
		
		// Client window stuf
		Font f = new Font("Courrier", Font.BOLD, 16);
		Label l = new Label(m_ResourcesBundle.getString("TrafficKey"));
		m_labelTraffic.setFont(f);
		m_labelTraffic.setForeground(Color.blue);
		l.setFont(f);
		Panel p = new Panel();
		p.setLayout(new FlowLayout());
		p.add(l);
		p.add(m_labelTraffic);
		this.add("North", new Label(" "));
		this.add("Center", p);
		m_labelStatusBar.setText(m_ResourcesBundle.getString("PortKey") + Integer.toString(m_iPort));
		this.add("South", m_labelStatusBar);
		
		this.pack();
	}
	
	public void setTraffic(double d)
	{
		m_labelTraffic.setText(Double.toString(d));
	}
	
	public synchronized boolean isRunnig()
	{
		return m_bRunnig;
	}

	// Component methods
	
	public Dimension getPreferredSize()
	{
		return new Dimension(300, 150);
	}
	
	// WindowListener methods

	public void windowOpened(WindowEvent e)
	{
	}
	
	public void windowClosed(WindowEvent e)
	{
		if (e.getWindow().equals((Window)this)) {
			m_bRunnig = false;
			System.exit(0);
		}
	}
		
	public void windowClosing(WindowEvent e)
	{
		if (e.getWindow().equals((Window)this)) {
			MessageBox msgBox = new MessageBox(this, this.getTitle(),
											   m_ResourcesBundle.getString("QuitKey"), 
											   MessageBox.MB_YES_NO | MessageBox.MB_ICON_QUESTION);
			int i = msgBox.getButtonPressed();
			if (i == msgBox.MB_YES)
				this.dispose();
		}
	}
	
	public void windowActivated(WindowEvent e)
	{
	}
	
	public void windowDeactivated(WindowEvent e)
	{
	}
	
	public void windowIconified(WindowEvent e)
	{
	}

	public void windowDeiconified(WindowEvent e)
	{
	}
		
	// ActionListener methods
	
	public void actionPerformed(ActionEvent e)
	{
		Object objSource = e.getSource();
		// Menu Items
		if (objSource instanceof MenuItem) {
			MenuItem menuItemS = (MenuItem)objSource;
			if (menuItemS.equals(menuItemFileExit)) {
				dispatchEvent(new WindowEvent(this, WindowEvent.WINDOW_CLOSING));
				return;
			}
			if (menuItemS.equals(menuItemHelpLicence)) {
				MessageBox msgBox = new MessageBox(this, m_ResourcesBundle.getString("LicenceTitleKey"), m_ResourcesBundle.getString("LicenceTextKey"), MessageBox.MB_OK);
				return;
			}
			if (menuItemS.equals(menuItemHelpAbout)) {
				MessageBox msgBox = new MessageBox(this, m_ResourcesBundle.getString("AboutTitleKey"), m_ResourcesBundle.getString("AboutTextKey"), MessageBox.MB_OK);
				return;
			}
		}
	}
	
	/**
	 * The main entry point for the application. 
	 * Creates a Window Frame with a Menu and a title.
	 *
	 * @param args Array of parameters passed to the application
	 * via the command line.
	 */
	public static void main(String args[])
	{
		int iPort = 0;
		ServerSocket serverSocket = null;
		
		try {
			if (args.length == 1) {
				iPort = Integer.parseInt(args[0]);
			}
			else {
				System.err.println("USAGE: ServerStub 'port'");
				System.exit(1);
			}
		}
		catch (NumberFormatException e) {
			System.err.println(e.getMessage());
			e.printStackTrace();
			System.err.println("USAGE: ServerStub 'port'");
			System.exit(2);
		}
		
		ServerStub mainFrame = new ServerStub(iPort);
		mainFrame.setVisible(true);

		// TCP/IP Server
		try {
			serverSocket = new ServerSocket(iPort);
			Random rnd = new Random();
			double d;
			while(mainFrame.isRunnig()) {
				d = (double)((long)(rnd.nextDouble() *  10000.0 ) / 100.0);
				String str = Double.toString(d) + "\n";
				Socket socket = serverSocket.accept();
				OutputStream outputStream = socket.getOutputStream();
				outputStream.write(str.getBytes());
				outputStream.close();
				socket.close();
				outputStream = null;
				socket = null;
				str = null;
				mainFrame.setTraffic(d);
			}
			serverSocket.close();
		}
		catch(IOException e) {
			System.err.println(e.getMessage());
			System.err.println(e.toString());
			e.printStackTrace();
		}
		catch(SecurityException e) {
			System.err.println(e.getMessage());
			System.err.println(e.toString());
			e.printStackTrace();
		}
		finally {
			try {
				if (serverSocket != null) {
					serverSocket.close();
					serverSocket = null;
				}
			}
			catch(IOException e) {
				System.err.println(e.getMessage());
				System.err.println(e.toString());
				e.printStackTrace();
			}
		}
	}
}
