//******************************************************************************
// Project: Simple LAN Monitor v1.00
// URL:		http://slam.sourceforge.net
// File:    WinUtil.java
//
// Description:
//          Windows utilitys for managing windows.
//
// Copyright (C) 2001:
//          Jos Caetano Silva (jcaetano@users.sourceforge.net)
//          Rui Fernando Ribeiro (ruiribeiro@users.sourceforge.net)
//
// Licence:
//          This program is free software; you can redistribute it and/or modify
//          it under the terms of the GNU General Public License as published by
//          the Free Software Foundation (read the 'GNU General Public 
//          License.htm' file, for more details).
// 
//          This program is distributed in the hope that it will be useful,
//          but WITHOUT ANY WARRANTY; without even the implied warranty of
//          MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
//          GNU General Public License for more details.
// 
//          You should have received a copy of the GNU General Public License
//          along with this program; if not, write to the Free Software
//          Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
//******************************************************************************

import java.awt.Rectangle;
import java.awt.Window;
import java.awt.Toolkit;
import java.awt.Graphics;
import java.awt.Color;

import InvalidParameter;


/**
  * Windows utilitys for managing windows.
  * 
  * @author		Jos Caetano A. C. Silva (jose.caetano@mail.telepac.pt)
  * @version	1.1, 1999-07-14
  * @since		1.0
  */
public class WinUtil extends Object {
	
	/**
	 * Centers a child window on a parent window.
	 * 
	 * @param		parent		The parent window. If <code>null</code>, the desktop window (the screen) is used insted.
	 * @param		child		The child window can't be <code>null</code>! If so, an exception is trown.
	 * @exception	InvalidParameter	If the child window is null, this exception is thrown.
	 * @since		1.0
	 */
	public synchronized static final void Center(Window parent, 
					Window child) throws InvalidParameter
	{
		Rectangle rectP = null;
		Rectangle rectC = null;
		int x;
		int y;
		
		// The child window can't be null
		if (child == null)
			throw new InvalidParameter("The child window can't be null!");

		rectC = child.getBounds();
		if (parent == null) {
			// Parent is the desktop screen
			rectP = new Rectangle(Toolkit.getDefaultToolkit().getScreenSize());
		}
		else {
			rectP = parent.getBounds();
		}
		// Move child to center
		x = rectP.x + (rectP.width - rectC.width) / 2;
		y = rectP.y + (rectP.height - rectC.height) / 2;
		child.setLocation(x , y);
	}
	
	public synchronized static final void Draw3DFrame(
					Graphics g, Rectangle rect, int size, 
					Color c1, Color c2, Color c3, Color c4)
	{
		// Variable inicialization
		int x = rect.x + size;
		int y = rect.y + size;
		int w = rect.width - size - 1;
		int h = rect.height - size - 1;
		int i;
		
		g.setColor(c1);
		g.drawLine(x, y, w, y);
		g.drawLine(x, y + 1, x, h - 1);

		g.setColor(c2);
		g.drawLine(x, h, w, h);
		g.drawLine(w, y + 1, w, h - 1);

		x = x + 1;
		y = y + 1;
		w = w - 1;
		h = h - 1;

		g.setColor(c3);
		g.drawLine(x, y, w, y);
		g.drawLine(x, y + 1, x, h - 1);

		g.setColor(c4);
		g.drawLine(x, h, w, h);
		g.drawLine(w, y + 1, w, h - 1);

		x = x + 1;
		y = y + 1;
		w = w - 1;
		h = h - 1;

		g.setColor(c4);
		g.drawLine(x, y, w, y);
		g.drawLine(x, y + 1, x, h - 1);

		g.setColor(c2);
		g.drawLine(x, h, w, h);
		g.drawLine(w, y + 1, w, h - 1);

		x = x + 1;
		y = y + 1;
		w = w - 1;
		h = h - 1;

		g.setColor(c1);
		g.drawLine(x, y, w, y);
		g.drawLine(x, y + 1, x, h - 1);

		g.setColor(c3);
		g.drawLine(x, h, w, h);
		g.drawLine(w, y + 1, w, h - 1);
	}
	
	public synchronized static final void Draw3DBorder(
					Graphics g, Rectangle rect, int size, 
					Color c1, Color c2, Color c3, Color c4)
	{
		// Variable inicialization
		int x = rect.x + size;
		int y = rect.y + size;
		int w = rect.width - size - 1;
		int h = rect.height - size - 1;
		int i;
		
		// Draw the border
		g.setColor(c1);
		g.drawLine(x, y, w - 1, y);
		g.drawLine(x, y + 1, x, h - 1);
			
		g.setColor(c4);
		g.drawLine(x, h, w - 1, h);
		g.drawLine(w, y, w, h);
			
		x = x + 1;
		y = y + 1;
		w = w - 1;
		h = h - 1;
		
		g.setColor(c3);
		g.drawLine(x, y, w - 1, y);
		g.drawLine(x, y + 1, x, h - 1);
			
		g.setColor(c2);
		g.drawLine(x, h, w - 1, h);
		g.drawLine(w, y, w, h);
	}
	
	public synchronized static final void Draw3DTickBorder(
					Graphics g, Rectangle rect, int size, 
					Color c1, Color c2)
	{
		// Variable inicialization
		int x = rect.x;
		int y = rect.y;
		int w = rect.width - 1;
		int h = rect.height - 1;
		int i;
		
		// Draw the border
		for (i = 0; i < size; i++) {
			g.setColor(c1);
			g.drawLine(x, y, w, y);
			g.drawLine(x, y + 1, x, h - 1);
			
			g.setColor(c2);
			g.drawLine(x, h, w, h);
			g.drawLine(w, y + 1, w, h - 1);
			
			x = x + 1;
			y = y + 1;
			w = w - 1;
			h = h - 1;
		}
	}
	
	public synchronized static final void DrawBorder(
					Graphics g, Rectangle rect, int size, 
					Color c)
	{
		// Variable inicialization
		int x = rect.x;
		int y = rect.y;
		int w = rect.width;
		int h = rect.height;
		int i;
		
		// Draw the border
		g.setColor(c);
		for (i = 0; i < size; i++) {
			g.drawRect(x, y, w, h);
			
			x = x + 1;
			y = y + 1;
			w = w - 2;
			h = h - 2;
		}
	}
}
