
/*
 * panic.c: error handling routines.
 *
 * Rui Ribeiro  <ruiribeiro@users.sourceforge.net>
 * Jose Caetano <jcaetano@users.sourceforge.net>
 *
 * Copyright Rui Ribeiro & Jose Silva
 * Licensed under GNU. Read ./LICENSE for the legalese.
 */
/*
 * panic.c: tratamento de erros
 *
 */
 
#include <stdio.h>
#include <stdlib.h>
#include <syslog.h>

/*
 * write_log: sends error message to syslog
 */
static write_log(unsigned priority, char * s )
{
	syslog(priority ,"%s", s);
}

/*
 * panic: write_log wrapper for unrecoverable errors
/*
 * invocado aquando de erros que nao se podem recuperar
 */
void panic( char * s )
{
	write_log(LOG_ERR, s);
	exit(EXIT_FAILURE);
}

/*
 * warning: write_log wrapper for recoverable errors
 */
/*
 * invocado aquando de erros
 */
void warning( char * s )
{
	write_log(LOG_WARNING, s);
}

/*
 * info: write_log wrapper for information messages
 */
void info( char * s )
{
	write_log(LOG_INFO, s);
}

/* EOF
 */
