/*
 * shm.c: sharing memory routines. Adapted from the LPG.
 *
 * Rui Ribeiro  <ruiribeiro@users.sourceforge.net>
 * Jose Caetano <jcaetano@users.sourceforge.net>
 *
 * Copyright Rui Ribeiro & Jose Silva
 * Licensed under GNU. Read ./LICENSE for the legalese.
 */
/*
 * shm.c: Rotinas para partilha de memria.
 *
 */

#include <stdio.h>
#include <sys/types.h>
#include <sys/ipc.h>
#include <sys/shm.h>

int addr_shmid;

/* oepnshmserver: shared memory zone creation
 */
/* rotina para criar zona de memoria partilhada 
 */
char * openshmserver(int segsize, char project_id)
{
        int   shmid, cntr;
        char * segptr;
        key_t  key;

        /* Create unique key via call to ftok() */
        key = ftok("/tmp", project_id);

        /* Open the shared memory segment - create if necessary */
        if((shmid = shmget(key, segsize, IPC_CREAT|IPC_EXCL|0666)) == -1) 
        {
           //perror("shmget");
           //exit(1);
           /* Segment probably already exists - try as a client */
           if((shmid = shmget(key, segsize, 0)) == -1)
              panic("shmget");
           //else
           //{
           //   shmctl(shmid, IPC_RMID, 0);
           //   if((shmid = shmget(key, segsize, IPC_CREAT|IPC_EXCL|0666)) == -1)
           //   {
           //       perror("shmget");
           //       exit(1);
           //   }
           // }
        }

        /* Attach (map) the shared memory segment into the current process */
        if((segptr = shmat(shmid, 0, 0)) == -1)
                panic("shmat");
        addr_shmid = shmid;
        return segptr;      
}

/*
 * openshmclient: routine to use shared memory zone
 */
/*
 * rotina para fechar zona de memoria partilhada
 */
char * openshmclient(int segsize, char project_id)
{
        int   shmid, cntr;
        char * segptr;
        key_t  key;

        /* Create unique key via call to ftok() */
        key = ftok("/tmp", project_id);


        /* Open the shared memory segment as a client */
        if((shmid = shmget(key, segsize, 0)) == -1) 
           panic("shmget");

        /* Attach (map) the shared memory segment into the current process */
        if((segptr = shmat(shmid, 0, 0)) == -1)
           panic("shmat");
        return segptr;
        
}

getshm(char project_id)
{
        // return segptr;
}

void deleteshm(char project_id)
{
        shmctl(addr_shmid, IPC_RMID, 0);
}

/*
 * closeshmclient: release shared memory zone.
 */
void closeshmclient(char * address)
{
   shmdt(address);
}

/* EOF
 */
 
