
/*
 * sniffclient.c: Reads shared mem. 
 *
 * Users TCP for delivering data.
 *
 * Rui Ribeiro  <ruiribeiro@users.sourceforge.net>
 * Jose Caetano <jcaetano@users.sourceforge.net>
 *
 * Copyright Rui Ribeiro & Jose Silva
 * Licensed under GNU. Read ./LICENSE for the legalese.
 */
/*
 * sniffclient.c: Fornece dados a aplicao cliente.
 * 
 * Processa valores devolvidos por daemon sniffer, e devolve dados atravs
 * de porta TCP.
 */
 
#include <stdio.h>
#include <stdlib.h>
#include <time.h>
#include <unistd.h>
#include <signal.h>
#include <syslog.h>
#include "h/shm.h"
#include "h/sniff.h"
#include "h/extern.h"
#include "h/version.h"

/* shared mem pointer
 */
/* apontador para memoria partilhada
 */
double * p_stats;

/* PID of program responsible for closing the shared memory handle
 */
/* guarda PID de processo que ter de libertar o cliente de  memoria partilhada
 */
pid_t process_pid;

/* calc_bandwidth: computes de network bandwidth
 */
/* funcao encarregue de calcular largura de banda momentanea
 */
void calc_bandwidth()
{
   double val;
   static double val_cp;
   static int first_time=1;
   
   if(first_time)
   {
      first_time--;
      /* copy var equals traffic var
       */
      /* coloca variavel de copia identica a valor de trafego
       */
      val_cp = p_stats[0];
   }
   
   /* make a copy, since it can be modified 
    */
   /* copia valor, uma vez que pode ser modificado de forma assincrona
    */
   val = p_stats[0];

   /* computes current bandwidth
    */
   /* calcula largura de banda corrente
    */
   bandwidth = (((val + ((val < val_cp)?MAGIC:0.0)) - val_cp) * 8 / 
		   1024)/NSECONDS;

   /* copies computed value for next computation
    */
   /* copia valor calculado para ser usado na proxima invocacao de funcao
    */
   val_cp = val;

   /* this function will be called again in NSECONDS time
    */
   /* programa a proxima invocacao desta funcao
    */
   alarm(NSECONDS);
}

/* 
 * leaving: since there are several instances running, we have to make sure
 * only the parent is releasing the shared mem handle
 */
/* ao sair, executa esta funcao -- ao vez que vrias cpias funcionam em
 * simultaneo, h que executar o cdigo pretendido no processo certo
 */
void leaving()
{
   if(process_pid == getpid())
   	closeshmclient((char *)p_stats);
}

/*
 * main: main entry
 */
/* funcao principal de cliente
 */
main(int argc, char **argv)
{
   /* valores
    */
   double val;
   double val_cp;
   int c;

   /*
    * program options handling
    */
   while((c = getopt(argc, argv, "p:s:hv")) != -1 )
   {
      switch(c)
      {
         case 'p':
		 tcpport = atoi(optarg);
		 if(tcpport < 1024)
		 {
	            printf("\nInvalid TCP port : port must be between 1024 and 65535 \n");
		    exit(EXIT_FAILURE);
		 }
		 break;
	 case 's':
		 shmemId = optarg[0];
		 break;
	 case 'h':
	 case 'v':
		 printf("%s : Simple LAN Monitor %s component\n", 
				 argv[0], VERSION);
		 printf("(c) 2001 Rui Fernando Ferreira Ribeiro\n");
		 printf("(c) 2001 Jose Caetano da Silva e Costa\n\n");
		 printf("This program is under the GNU license.\n\n");
		 printf("Usage: %s [-p <tcp port>][-s c]\n <tcp port> is the port\
 to listen for client requests\n", argv[0]);
		printf( " <tcp port> is by default 5000\n\n");
		printf(" <c> is a shared memory identifier in order for\n");
		printf(" being able to run multiple sniffserver/sniffclient\n");
                printf(" pairs in the same server\n");
		exit(EXIT_FAILURE);
			
	 default:
		 printf("Invalid option. Try %s -h for more info\n",
			argv[0]);
		 exit(EXIT_FAILURE);
      }
   }

   openlog(argv[0], LOG_PID, LOG_USER);
   
   p_stats = (double *)NULL;

   /* request shared memory
    */
   /* obtem memoria partilhada
    */
   p_stats = (double *) openshmclient(sizeof(double), shmemId);
   if(p_stats == (double *)NULL)
      {
	      printf("\nProblems requesting shared memory \n");
	      printf("The sniffer software isn't running\n");
	      exit(EXIT_FAILURE);
      }

   /* turns process into daemon. Detaches it from the terminal
    */
   /* transforma processo em daemon, realizando detach do terminal
    */
   daemon_start(1);

   /* abandons root privileges, for security reasons
    */
   /* abandona privilegios de root, por motivos de seguranca
    */
   leave_suid();
   
   process_pid = getpid();

   /* registers function for executing upon program termination
    */
   /* ao sair, executa funcao
    */
   atexit(leaving);

   /* Programs the first execution of calc_bandwidth
    */
   signal(SIGALRM, calc_bandwidth);
   alarm(NSECONDS);

   /* main TCP server cycle
    */
   /* ciclo principal de servidor TCP
    */
   while(1)
   {
	   tcp_server();
   }
   /* return is never executed. Just placed for the disposing of compiler
    * warning.
    */
   /* colocado aqui para eliminar warning de compilador
    */
   return (EXIT_SUCCESS);
}

/* EOF
 */
