
/*
 * Routines for network traffic sniffing.
 *
 * Rui Ribeiro  <ruiribeiro@users.sourceforge.net>
 * Jose Caetano <jcaetano@users.sourceforge.net>
 *
 * Copyright Rui Ribeiro & Jose Silva
 * Licensed under GNU. Read ./LICENSE for the legalese.
 */
/*
 * sniffserver.c: Escuta de meio de transmissao.
 *
 * Este programa escuta o meio de transmissao, contabiliza os bytes que 
 * transitam pelo meio e coloca os valores numa zona de memoria partilhada.
 */

#include <unistd.h>
#include <stdio.h>
#include <stdlib.h>
#include <syslog.h>
#include <pcap.h>
#include <time.h>

#include "h/shm.h"
#include "h/sniff.h"
#include "h/version.h"
#include "h/extern.h"

/* shared mem handler
 */
/* variaver apontadora para valores de trafego
 */
double * p_stats;

/* keeps PID of process reponsible for releasing shared mem handler
 */
/* guarda PID de processo que ter de libertar a memoria partilhada
 */
pid_t process_pid;

/*
 * callback_f: function called in the reception of each packet 
 * matching the BPF filter
 */
/* Funcao invocada de forma assincrona na recepcao de *cada* pacote
 */
void callback_f(u_char *user, const struct pcap_pkthdr *h, 
		const u_char *p)
   { 
    static first_time = 1;
   
    if (first_time)
    {
       leave_suid();
       first_time--;
    }
    p_stats[0] += (double)h->len;
    if (p_stats[0] > MAGIC)
       p_stats[0] -= MAGIC;
   }

/*
 * leaving: release shared mem handler
 */
/* executa esta funcao ao sair do programa -- uma vez que vrias cpias 
 * funcionam em simultaneo, h que executar o cdigo pretendido no
 * processo certo
 */
void leaving()
{
   if (process_pid == getpid())
   	closeshmclient((char *)p_stats);
}


int main(argc, argv)
int argc;
char ** argv;
   {
   /* actual memory space used by bandwith var
    */
   /* p funciona como deposito de variavel de ocupacao de largura de banda
    * (i.e. representa a memria partilhada)
    */
   static double p;
   int c;
   char sniff_nic[10] = "";
   int promisc = 1;

   /* program option handling
    */
   while((c = getopt(argc, argv, "i:ps:hv")) != -1 )
   {
      switch(c)
      {
         case 'i':
	         strncpy(sniff_nic, optarg, 9);
	    break;
	 case 'p':
	         promisc = 0;
	    break;
	 case 's':
		 shmemId = optarg[0];
		 break;
	 case 'h':
	 case 'v':
	         printf("%s : Simple LAN Monitor %s component\n",
				 argv[0], VERSION);

		 printf("(c) 2001 Rui Fernando Ferreira Ribeiro\n");
		 printf("(c) 2001 Jose Caetano da Silva e Costa\n\n");
		 printf("This program is under the GNU license.\n\n");

	         printf("Usage: %s [-i interface][-p][-s c][bpf string]\n", argv[0]);
		 printf("-i defines the network interface where the traffic\n\
is sniffed/measured\n");
	         printf("-p Don't enable promisc mode\n\n");
		 printf(" <c> is a shared memory identifier in order for\n");
		 printf(" being able to run multiple sniffserver/sniffclient\n");
                 printf(" pairs in the same server\n");
		 exit(EXIT_FAILURE);
		 
	 default:
	    	printf("Invalid option. Try %s -h for more info\n",
			argv[0]);
		exit(EXIT_FAILURE);
      }
   }

   
   openlog(argv[0], LOG_PID, LOG_USER);
   p_stats = &p;

   p_stats = (double *) openshmserver(20 * sizeof(double), shmemId);

   /* inicializa valor */
   p_stats[0] = 0.0;

   daemon_start(1); 

   process_pid = getpid();
   atexit(leaving);
   
   /* calls main sniffer cycle
    */
   /* invoca ciclo principal de sniffer
    */
   sniffer_bpf((optind < argc)?argv[optind]:NULL, sniff_nic, promisc); 

   return(EXIT_SUCCESS);
   }
   
/* EOF
 */
 
