
/*
 * tcpserver: implements sniffclient's TCP server.
 *
 * Returns local network usage data to client.
 * 
 * Rui Ribeiro  <ruiribeiro@users.sourceforge.net>
 * Jose Caetano <jcaetano@users.sourceforge.net>
 *
 * Copyright Rui Ribeiro & Jose Silva
 * Licensed under GNU. Read ./LICENSE for the legalese.
 */
/*
 * tcpserver.c: servidor de TCP com comunicao directa com cliente.
 *
 * Calcula e fornece dados de ocupao de rede a cliente.
 */

#include <stdio.h>
#include <stdlib.h>
#include <errno.h>
#include <string.h>
#include <signal.h>
#include <sys/types.h>
#include <netinet/in.h>
#include <sys/socket.h>
#include <sys/wait.h>

#include "h/sniff.h"
#include "h/extern.h"

tcp_server()
{
    int sockfd, new_fd;  /* listen on sock_fd, new connection on new_fd */

    /* local sockets info
     */
    /* informacoes sobre sockets locais
     */
    struct sockaddr_in server_addr; 

    /* client socket
     */
    /* informacoes do socket cliente */
    struct sockaddr_in client_addr; 
    int sin_size;

    /* vars used from syncing parent and childs
     */
    /* variaveis usada para sincronizacao entre pais e filhos, na escuta de
     * transacoes TCP
     */
    int    pid;
    union  wait status;
    int one = 1;

    if ((sockfd = socket(AF_INET, SOCK_STREAM, 0)) == -1) {
        panic("tcp_server:socket");
    }

    memset(&server_addr, 0, sizeof(struct sockaddr_in));

    /* data setup for socket initialisation
     */
    /* setup de dados para inicializacao de socket */
    server_addr.sin_family = AF_INET;         
    server_addr.sin_port = htons(tcpport);    
    server_addr.sin_addr.s_addr = INADDR_ANY; 

    if (bind(sockfd, (struct sockaddr *)&server_addr, sizeof(struct sockaddr)) == -1) {
        panic("tcp_server:bind");
    }
    
    setsockopt(sockfd, SOL_SOCKET, SO_REUSEADDR, (char *)&one, sizeof(int));

    if (listen(sockfd, NCLIENTS) == -1) {
        panic("tcp_server:listen");
    }

    while(1) {  /* main accept() loop */
        sin_size = sizeof(struct sockaddr_in);
        if ((new_fd = accept(sockfd, (struct sockaddr *)&client_addr, &sin_size)) == -1) {
            warning("tcp_server:accept");
            continue;
        }
        if (!fork()) { /* this is the child process */
	    char s[20];

	    snprintf(s, 19, "%.2lf\n", bandwidth);
            if (send(new_fd, s, strlen(s), 0) == -1)
                warning("tcp_server:send");
            close(new_fd);
            exit(0);
        }
	else  
           close(new_fd); 

	/* clean process in WAIT state -- avoids zombies
	 */
	/* limpa informacoes sobre processos em espera para terminar
	 * -- evita zombies
	 */
        while( (pid = wait3(&status, WNOHANG, (struct rusage *) 0)) > 0)
		;
    }
}

/* EOF
 */
 
